OGGM Enhancement Proposals (OEPs)
=================================

OGGM Enhancement Proposals (OEPs) are design documents describing mid- to long
term goals of OGGM. Anyone can write or edit OEPs - and anyone is welcome to
tackle the implementation of these goals!

See `this github issue <https://github.com/OGGM/oggm/issues/805>`_ for a
discussion about OEPs.

.. toctree::
    :maxdepth: 1

    oeps/oep--0001-dependencies.rst
    oeps/oep--0002-cloud.rst
    oeps/oep--0003-smb.rst
